=== modified file 'NEWS'
--- NEWS	2010-09-21 10:48:23 +0000
+++ NEWS	2010-09-23 07:40:07 +0000
@@ -467,6 +467,39 @@
   (Andrew Bennetts, #625574)
 
 
+bzr 2.2.2
+#########
+
+:2.2.2: NOT RELEASED YET
+
+Compatibility Breaks
+********************
+
+New Features
+************
+
+Bug Fixes
+*********
+
+Improvements
+************
+
+Documentation
+*************
+
+API Changes
+***********
+
+Internals
+*********
+
+Testing
+*******
+
+* Fix tests that failed when run under ``LANG=C``.
+  (Andrew Bennetts, #632387)
+
+
 bzr 2.2.1
 #########
 

=== modified file 'bzrlib/tests/blackbox/test_alias.py'
--- bzrlib/tests/blackbox/test_alias.py	2010-08-29 14:32:45 +0000
+++ bzrlib/tests/blackbox/test_alias.py	2010-09-23 07:40:07 +0000
@@ -46,6 +46,9 @@
 
     def test_unicode_alias(self):
         """Unicode aliases should work (Bug #529930)"""
+        # XXX: strictly speaking, lack of unicode filenames doesn't imply that
+        # unicode command lines aren't available.
+        self.requireFeature(tests.UnicodeFilenameFeature)
         file_name = u'foo\xb6'
 
         tree = self.make_branch_and_tree('.')

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2010-07-14 08:53:58 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2010-09-23 02:56:19 +0000
@@ -33,6 +33,7 @@
 from bzrlib.tests import (
     probe_bad_non_ascii,
     TestSkipped,
+    UnicodeFilenameFeature,
     )
 from bzrlib.tests import TestCaseWithTransport
 
@@ -112,6 +113,7 @@
     def test_unicode_commit_message_is_filename(self):
         """Unicode commit message same as a filename (Bug #563646).
         """
+        self.requireFeature(UnicodeFilenameFeature)
         file_name = u'\N{euro sign}'
         self.run_bzr(['init'])
         open(file_name, 'w').write('hello world')

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2010-06-11 07:32:12 +0000
+++ bzrlib/tests/blackbox/test_export.py	2010-09-23 02:56:19 +0000
@@ -66,15 +66,13 @@
         self.assertEqual(['test/a'], sorted(ball.getnames()))
 
     def test_tar_export_unicode(self):
+        self.requireFeature(tests.UnicodeFilenameFeature)
         tree = self.make_branch_and_tree('tar')
         # FIXME: using fname = u'\xe5.txt' below triggers a bug revealed since
         # bzr.dev revno 4216 but more related to OSX/working trees/unicode than
         # export itself --vila 20090406
         fname = u'\N{Euro Sign}.txt'
-        try:
-            self.build_tree(['tar/' + fname])
-        except UnicodeError:
-            raise tests.TestSkipped('Unable to represent path %r' % (fname,))
+        self.build_tree(['tar/' + fname])
         tree.add([fname])
         tree.commit('first')
 
@@ -87,6 +85,7 @@
 
     def test_tar_export_unicode_basedir(self):
         """Test for bug #413406"""
+        self.requireFeature(tests.UnicodeFilenameFeature)
         basedir = u'\N{euro sign}'
         os.mkdir(basedir)
         os.chdir(basedir)
@@ -119,12 +118,10 @@
         self.assertEqual(['test/a'], sorted(zfile.namelist()))
 
     def test_zip_export_unicode(self):
+        self.requireFeature(tests.UnicodeFilenameFeature)
         tree = self.make_branch_and_tree('zip')
         fname = u'\N{Euro Sign}.txt'
-        try:
-            self.build_tree(['zip/' + fname])
-        except UnicodeError:
-            raise tests.TestSkipped('Unable to represent path %r' % (fname,))
+        self.build_tree(['zip/' + fname])
         tree.add([fname])
         tree.commit('first')
 

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2010-07-08 09:11:44 +0000
+++ bzrlib/tests/test_osutils.py	2010-09-23 02:56:19 +0000
@@ -21,7 +21,6 @@
 import os
 import re
 import socket
-import stat
 import sys
 import time
 
@@ -2076,5 +2075,12 @@
 
     def test_unicode_user(self):
         ue = osutils.get_user_encoding()
-        osutils.set_or_unset_env('LOGNAME', u'jrandom\xb6'.encode(ue))
-        self.assertEqual(u'jrandom\xb6', osutils.getuser_unicode())
+        uni_val, env_val = tests.probe_unicode_in_user_encoding()
+        if uni_val is None:
+            raise tests.TestSkipped(
+                'Cannot find a unicode character that works in encoding %s'
+                % (osutils.get_user_encoding(),))
+        uni_username = u'jrandom' + uni_val
+        encoded_username = uni_username.encode(ue)
+        osutils.set_or_unset_env('LOGNAME', encoded_username)
+        self.assertEqual(uni_username, osutils.getuser_unicode())

